@@ -31,6 +31,7 @@ typedef enum {
 	KASPDBKEY_MASTERSERIAL = 0x5,
 	KASPDBKEY_LASTSIGNEDSERIAL = 0x6,
 	KASPDBKEY_OFFLINE_RECORDS = 0x7,
+	KASPDBKEY_SAVED_TTLS = 0x8,
 } keyclass_t;
 
 static MDB_val make_key_str(keyclass_t kclass, const knot_dname_t *dname, const char *str)
@@ -43,6 +44,7 @@ static MDB_val make_key_str(keyclass_t kclass, const knot_dname_t *dname, const
 	case KASPDBKEY_NSEC3TIME:
 	case KASPDBKEY_LASTSIGNEDSERIAL:
 	case KASPDBKEY_MASTERSERIAL:
+	case KASPDBKEY_SAVED_TTLS:
 		assert(dname != NULL && str == NULL);
 		return knot_lmdb_make_key("BN", (int)kclass, dname);
 	case KASPDBKEY_PARAMS:
@@ -92,12 +94,12 @@ static MDB_val params_serialize(const key_params_t *params)
 	flags |= (params->is_pub_only ? 0x04 : 0);
 	flags |= (params->is_csk ? 0x08 : 0);
 
-	return knot_lmdb_make_key("LLHBBLLLLLLLLLD", (uint64_t)params->public_key.size,
-		(uint64_t)0, params->keytag, params->algorithm, flags,
+	return knot_lmdb_make_key("LLHBBLLLLLLLLLDL", (uint64_t)params->public_key.size,
+		(uint64_t)sizeof(params->timing.revoke), params->keytag, params->algorithm, flags,
 		params->timing.created, params->timing.pre_active, params->timing.publish,
 		params->timing.ready, params->timing.active, params->timing.retire_active,
 		params->timing.retire, params->timing.post_active, params->timing.remove,
-		params->public_key.data, params->public_key.size);
+		params->public_key.data, params->public_key.size, params->timing.revoke);
 }
 
 // this is no longer compatible with keys created by Knot 2.5.x (and unmodified since)
@@ -126,6 +128,15 @@ static bool params_deserialize(const MDB_val *val, key_params_t *params)
 		params->is_pub_only = ((flags & 0x04) ? true : false);
 		params->is_csk = ((flags & 0x08) ? true : false);
 
+		if (future > 0) {
+			if (future < sizeof(params->timing.revoke)) {
+				free(params->public_key.data);
+				return false;
+			}
+			// 'revoked' timer is part of 'future' section since it was added later
+			params->timing.revoke = be64toh(*(uint64_t *)(val->mv_data + val->mv_size - future));
+		}
+
 		if ((flags & 0x02) && (params->is_ksk || !params->is_csk)) {
 			return true;
 		}
@@ -234,13 +245,11 @@ int kasp_db_sweep(knot_lmdb_db_t *db, sweep_cb keep_zone, void *cb_data)
 	}
 	knot_lmdb_txn_t txn = { 0 };
 	knot_lmdb_begin(db, &txn, true);
-	bool found = knot_lmdb_first(&txn);
-	while (found) {
+	knot_lmdb_forwhole(&txn) {
 		if (*(const uint8_t *)txn.cur_key.mv_data != KASPDBKEY_POLICYLAST &&
 		    !keep_zone((const knot_dname_t *)txn.cur_key.mv_data + 1, cb_data)) {
 			knot_lmdb_del_cur(&txn);
 		}
-		found = knot_lmdb_next(&txn);
 	}
 	knot_lmdb_commit(&txn);
 	return txn.ret;
@@ -468,6 +477,28 @@ int kasp_db_delete_offline_records(knot_lmdb_db_t *db, const knot_dname_t *zone,
 	return txn.ret;
 }
 
+int kasp_db_get_saved_ttls(knot_lmdb_db_t *db, const knot_dname_t *zone,
+                           uint32_t *max_ttl, uint32_t *key_ttl)
+{
+	MDB_val key = make_key_str(KASPDBKEY_SAVED_TTLS, zone, NULL);
+	knot_lmdb_txn_t txn = { 0 };
+	knot_lmdb_begin(db, &txn, false);
+	if (knot_lmdb_find(&txn, &key, KNOT_LMDB_EXACT | KNOT_LMDB_FORCE)) {
+		knot_lmdb_unmake_curval(&txn, "II", max_ttl, key_ttl);
+	}
+	knot_lmdb_abort(&txn);
+	free(key.mv_data);
+	return txn.ret;
+}
+
+int kasp_db_set_saved_ttls(knot_lmdb_db_t *db, const knot_dname_t *zone,
+                           uint32_t max_ttl, uint32_t key_ttl)
+{
+	MDB_val key = make_key_str(KASPDBKEY_SAVED_TTLS, zone, NULL);
+	MDB_val val = knot_lmdb_make_key("II", max_ttl, key_ttl);
+	return knot_lmdb_quick_insert(db, key, val);
+}
+
 void kasp_db_ensure_init(knot_lmdb_db_t *db, conf_t *conf)
 {
 	if (db->path == NULL) {
@@ -478,3 +509,24 @@ void kasp_db_ensure_init(knot_lmdb_db_t *db, conf_t *conf)
 		assert(db->path != NULL);
 	}
 }
+
+int kasp_db_backup(const knot_dname_t *zone, knot_lmdb_db_t *db, knot_lmdb_db_t *backup_db)
+{
+	size_t n_prefs = 8; // NOTE: this and following must match number of record types
+	MDB_val prefixes[n_prefs];
+	prefixes[0] = make_key_str(KASPDBKEY_PARAMS, zone, NULL);
+	prefixes[1] = knot_lmdb_make_key("B", KASPDBKEY_POLICYLAST); // we copy all policy-last records, that doesn't harm
+	prefixes[2] = make_key_str(KASPDBKEY_NSEC3SALT, zone, NULL);
+	prefixes[3] = make_key_str(KASPDBKEY_NSEC3TIME, zone, NULL);
+	prefixes[4] = make_key_str(KASPDBKEY_MASTERSERIAL, zone, NULL);
+	prefixes[5] = make_key_str(KASPDBKEY_LASTSIGNEDSERIAL, zone, NULL);
+	prefixes[6] = make_key_str(KASPDBKEY_OFFLINE_RECORDS, zone, NULL);
+	prefixes[7] = make_key_str(KASPDBKEY_SAVED_TTLS, zone, NULL);
+
+	int ret = knot_lmdb_copy_prefixes(db, backup_db, prefixes, n_prefs);
+
+	for (int i = 0; i < n_prefs; i++) {
+		free(prefixes[i].mv_data);
+	}
+	return ret;
+}
