@@ -224,6 +224,31 @@ int kasp_db_load_offline_records(knot_lmdb_db_t *db, const knot_dname_t *for_dna
 int kasp_db_delete_offline_records(knot_lmdb_db_t *db, const knot_dname_t *zone,
                                    knot_time_t from_time, knot_time_t to_time);
 
+/*!
+ * \brief Load saved zone-max-TTL and DNSKEY-TTL.
+ *
+ * \param db        KASP db.
+ * \param max_ttl   Out: saved zone max TTL.
+ * \param key_ttl   Out: saved DNSKEY TTL.
+ *
+ * \retval KNOT_ENOENT   If not saved yet.
+ * \return KNOT_E*
+ */
+int kasp_db_get_saved_ttls(knot_lmdb_db_t *db, const knot_dname_t *zone,
+                           uint32_t *max_ttl, uint32_t *key_ttl);
+
+/*!
+ * \brief Save current zone-max-TTL and DNSKEY-TTL.
+ *
+ * \param db        KASP db.
+ * \param max_ttl   Current zone max TTL.
+ * \param key_ttl   Current DNSKEY TTL.
+ *
+ * \return KNOT_E*
+ */
+int kasp_db_set_saved_ttls(knot_lmdb_db_t *db, const knot_dname_t *zone,
+                           uint32_t max_ttl, uint32_t key_ttl);
+
 /*!
  * \brief Initialize KASP database according to conf, if not already.
  *
@@ -231,3 +256,14 @@ int kasp_db_delete_offline_records(knot_lmdb_db_t *db, const knot_dname_t *zone,
  * \param conf    COnfiguration to take options from.
  */
 void kasp_db_ensure_init(knot_lmdb_db_t *db, conf_t *conf);
+
+/*!
+ * \brief Backup KASP DB for one zone with keys and all metadata to backup location.
+ *
+ * \param zone         Name of the zone to be backed up.
+ * \param db           DB to backup from.
+ * \param backup_db    DB to backup to.
+ *
+ * \return KNOT_E*
+ */
+int kasp_db_backup(const knot_dname_t *zone, knot_lmdb_db_t *db, knot_lmdb_db_t *backup_db);
