@@ -1,4 +1,4 @@
-/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2020 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -69,6 +69,7 @@ int knot_dnssec_sign_process_events(const kdnssec_ctx_t *kctx,
  * \param update       Zone Update structure with current zone contents to be updated by signing.
  * \param flags        Zone signing flags.
  * \param roll_flags   Key rollover flags.
+ * \param adjust_now   If not zero: adjust "now" to this timestamp.
  * \param reschedule   Signature refresh time of the oldest signature in zone.
  *
  * \return Error code, KNOT_EOK if successful.
@@ -76,6 +77,7 @@ int knot_dnssec_sign_process_events(const kdnssec_ctx_t *kctx,
 int knot_dnssec_zone_sign(zone_update_t *update,
                           zone_sign_flags_t flags,
                           zone_sign_roll_flags_t roll_flags,
+                          knot_time_t adjust_now,
                           zone_sign_reschedule_t *reschedule);
 
 /*!
@@ -114,3 +116,13 @@ int knot_dnssec_nsec3resalt(kdnssec_ctx_t *ctx, knot_time_t *salt_changed, knot_
  * \return Timestamp of next signing attempt.
  */
 knot_time_t knot_dnssec_failover_delay(const kdnssec_ctx_t *ctx);
+
+/*!
+ * \brief Validate zone DNSSEC based on its contents.
+ *
+ * \param update         Zone update with contents.
+ * \param incremental    Try to validate incrementally.
+ *
+ * \return KNOT_E*
+ */
+int knot_dnssec_validate_zone(zone_update_t *update, bool incremental);
