@@ -68,10 +68,16 @@ int event_load(conf_t *conf, zone_t *zone)
 	// If configured, load journal contents.
 	if (load_from == JOURNAL_CONTENT_ALL && !old_contents_exist && zf_from != ZONEFILE_LOAD_WHOLE) {
 		ret = zone_load_from_journal(conf, zone, &journal_conts);
-		if (ret != KNOT_EOK && ret != KNOT_ENOENT) {
+		switch (ret) {
+		case KNOT_EOK:
+			zone_in_journal_exists = true;
+			break;
+		case KNOT_ENOENT:
+			zone_in_journal_exists = false;
+			break;
+		default:
 			goto cleanup;
 		}
-		zone_in_journal_exists = true;
 	} else {
 		zone_in_journal_exists = zone_journal_has_zij(zone);
 	}
@@ -181,6 +187,7 @@ int event_load(conf_t *conf, zone_t *zone)
 					                 "zone file changed with SOA serial %s, "
 					                 "ignoring zone file and loading from journal",
 					                 (ret == KNOT_ESEMCHECK ? "unupdated" : "decreased"));
+					zone_contents_deep_free(zf_conts);
 					ret = zone_update_from_contents(&up, zone, journal_conts, UPDATE_HYBRID);
 				}
 			}
