@@ -1,4 +1,4 @@
-/*  Copyright (C) 2018 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "contrib/net.h"
@@ -81,17 +81,17 @@ static knotd_state_t dnsproxy_fwd(knotd_state_t state, knot_pkt_t *pkt,
 	};
 
 	/* Create a forwarding request. */
-	struct knot_requestor re;
+	knot_requestor_t re;
 	int ret = knot_requestor_init(&re, capture, &capture_param, qdata->mm);
 	if (ret != KNOT_EOK) {
 		return state; /* Ignore, not enough memory. */
 	}
 
 	bool is_tcp = net_is_stream(qdata->params->socket);
-	const struct sockaddr *dst = (const struct sockaddr *)&proxy->remote;
-	const struct sockaddr *src = (const struct sockaddr *)&proxy->via;
-	struct knot_request *req = knot_request_make(re.mm, dst, src, qdata->query, NULL,
-	                                             is_tcp ? 0 : KNOT_RQ_UDP);
+	const struct sockaddr_storage *dst = &proxy->remote;
+	const struct sockaddr_storage *src = &proxy->via;
+	knot_request_t *req = knot_request_make(re.mm, dst, src, qdata->query, NULL,
+	                                        is_tcp ? 0 : KNOT_REQUEST_UDP);
 	if (req == NULL) {
 		knot_requestor_clear(&re);
 		return state; /* Ignore, not enough memory. */
