@@ -1,4 +1,4 @@
-/*  Copyright (C) 2018 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -11,8 +11,8 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ */
 
 #include <assert.h>
 #include <gnutls/abstract.h>
@@ -30,7 +30,6 @@
 #include "libdnssec/shared/keyid_gnutls.h"
 #include "libdnssec/keystore.h"
 #include "libdnssec/keytag.h"
-#include "libdnssec/shared/pem.h"
 #include "libdnssec/shared/shared.h"
 #include "libdnssec/shared/binary_wire.h"
 #include "contrib/wire_ctx.h"
