@@ -388,12 +388,16 @@ int https_ctx_connect(https_ctx_t *ctx, const int sockfd, struct sockaddr_storag
 
 	// Save authority server
 	if (ctx->authority == NULL) {
-		ctx->authority = (char*)calloc(HTTPS_AUTHORITY_LEN, sizeof(char));
-		ret = sockaddr_to_authority(ctx->authority, HTTPS_AUTHORITY_LEN, address);
-		if (ret != KNOT_EOK) {
-			free(ctx->authority);
-			ctx->authority = NULL;
-			return KNOT_EINVAL;
+		if (remote != NULL) {
+			ctx->authority = strdup(remote);
+		} else {
+			ctx->authority = (char*)calloc(HTTPS_AUTHORITY_LEN, sizeof(char));
+			ret = sockaddr_to_authority(ctx->authority, HTTPS_AUTHORITY_LEN, address);
+			if (ret != KNOT_EOK) {
+				free(ctx->authority);
+				ctx->authority = NULL;
+				return KNOT_EINVAL;
+			}
 		}
 	}
 
